@@ -25,19 +25,20 @@
 #define IF97_PT		611.657e-06	/* MPa */
 
 typedef enum {
-	IF97_UNDEF = 0,
-	IF97_WATER = 1,
-	IF97_STEAM = 2,
-	IF97_SUPER = 3,
-	IF97_SAT   = 4,
-	IF97_GAS   = 5,
+	IF97_REGION_UNDEF = 0,
+	IF97_REGION_1 = 1,
+	IF97_REGION_2 = 2,
+	IF97_REGION_3 = 3,
+	IF97_REGION_4 = 4,
+	IF97_REGION_5 = 5,
 } if97_region_id;
 
 iapws_state_id if97_state(double p, double t);
 if97_region_id if97_region(double p, double t);
+if97_region_id if97_region_ph(double p, double h);
 double if97_tsat(double p);
 double if97_psat(double t);
 int if97_gamma(double p, double t, iapws_state_id state, iapws_phi *gamma);
-//void if97_gamma_rhot(double rho, double t, iapws_phi *gamma);
+int if97_gamma_ph(double p, double h, iapws_phi *gamma);
 
 #endif
